@@ -49,7 +49,9 @@ var scoreNames = {
     'fm': 'Frequency per Million',
     'lf': 'log Frequency',
     'lfm': 'log Frequency per Million',
-    'mi': 'Mutual Information',
+    'milf': 'Pointwise Mutual Information * log Frequency',
+    'mi1': 'Pointwise Mutual Information',
+    'mi3': 'Mutual Information^3',
     'ld': 'log Dice',
     'll': 'log Likelihood'
 };
